Preview of the proposed up-rust native-frame-model branch (up-rust b6b99c6d, up-spec f0e9b17) — not released documentation. branch · write-up

Struct SubscriptionInfo

#[repr(C)]
pub struct SubscriptionInfo { /* private fields */ }
One active subscription as reported by the uSubscription service.

Implementations

Source

impl SubscriptionInfo

pub fn new( topic: UUri, subscriber: UUri, status: SubscriptionStatus, expiration: Option<u64>, min_sample_period: Option<u32>, ) -> Self

Creates a new info object.

Arguments
  • topic - The topic of the subscription.
  • subscriber - The uEntity that has established the subscription.
  • status - The status of the subscription.
  • expiration - The point in time at which the subscription expires (milliseconds since Unix epoch). If not specified, the subscription is valid until explicitly unsubscribed.
  • min_sample_period - The minimum duration (in seconds) between two events that should be maintained for remote only topics. Device dispatchers use this attribute to reduce the publication rates of events sent between devices. This attribute is commonly used for mobile/cloud components subscribing to vehicle topics that are published at a high rate. If the desired sampling period set by the subscriber is lower than the original publisher’s publication period, the attribute is ignored. If not specified, the sampling period is set by the publisher.
pub fn topic(&self) -> &UUri

Returns the subscribed topic.

pub fn subscriber(&self) -> &UUri

Returns the subscriber’s URI.

pub fn status(&self) -> &SubscriptionStatus

Returns the subscription’s current status.

pub fn expiration(&self) -> &Option<u64>

Returns the subscription’s expiration time, if bounded.

pub fn min_sample_period(&self) -> &Option<u32>

Returns the minimum sample period, if rate-limited.

pub fn has_status(&self, state: SubscriptionStatus) -> bool

Checks for a specific subscription status.

Examples
use up_rust::{communication::SubscriptionStatus, UUri};
use up_rust::core::usubscription::SubscriptionInfo;

let subscription_info = SubscriptionInfo::new(
    UUri::try_from("/A100/1/9000").unwrap(),
    UUri::try_from("//subscriber/ABCD/1/0").unwrap(),
    SubscriptionStatus::Subscribed,
    None,
    None,
);
assert!(subscription_info.has_status(SubscriptionStatus::Subscribed));
assert!(!subscription_info.has_status(SubscriptionStatus::Unsubscribed));